#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 megaparsec
version:              9.7.0
visibility:           public
id:                   megaparsec-9.7.0-BQSYqoXI2TY61xEmJ10u8L
key:                  megaparsec-9.7.0-BQSYqoXI2TY61xEmJ10u8L
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that tries to find a nice balance
    between speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  1b0a58f67b5398235dd62ac93860833a
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Binary
    Text.Megaparsec.Byte.Lexer Text.Megaparsec.Char
    Text.Megaparsec.Char.Lexer Text.Megaparsec.Debug
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Internal Text.Megaparsec.Pos Text.Megaparsec.State
    Text.Megaparsec.Stream Text.Megaparsec.Unicode

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer

import-dirs:          /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-megaparsec
hs-libraries:         HSmegaparsec-9.7.0-BQSYqoXI2TY61xEmJ10u8L
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KRBUDrDZZz8K0kWnqUEh6i containers-0.6.7
    deepseq-1.4.8.1 mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    scientific-0.3.8.1-5xEN5FH7FNLBtMgMgahhk5 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

